# MyDM
### 一个使用OneBot v11/12协议的机器人框架
- 暂时只支持 go-cqhttp，写的代码也都是为了go-cqhttp，目前并没有使用别的OneBot实现的打算
- 暂时只支持 array 上报数据类型
- 暂时只支持 正向Http 和 正向WebSocket 通信协议

## ~~食用~~使用教程
1. 使用pip安装 `pip install mydm` (如果希望使用ujson代替json，可以使用`pip install mydm[all]`)
2. 然后就可以愉快的使用了

## 举个~~栗子~~例子
[demo.py](demo.py)
